@@ -13,31 +13,56 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <QtGui>
-#include <QFlags>
-
 #include "mainwindow.h"
-#include "trainingselectionview.h"
-#include "querymeesettings.h"
 
 MainWindow::MainWindow()
 {
     TrainingSelectionView* trainingView = new TrainingSelectionView(this);
 
+    connect(this,
+            SIGNAL(updateFileList()),
+            trainingView,
+            SLOT(slotInitView()));
+
     createActions();
     createMenus();
     setCentralWidget(trainingView);
+
 }
 
 void MainWindow::createActions(){
+
+
     settingAction = new QAction(tr("Open dictionary"), this);
     connect(settingAction,
             SIGNAL(triggered()),
             QueryMeeSettings::instance(),
             SLOT(openDictionary()));
+
+
+    downloadAction = new QAction(tr("Download KVTML files"), this);
+    connect(downloadAction,
+            SIGNAL(triggered()),
+            this,
+            SLOT(downloadFiles()));
 }
 
 void MainWindow::createMenus(){
     mainMenu = menuBar()->addMenu("Main");
     mainMenu->addAction(settingAction);
+    mainMenu->addAction(downloadAction);
 }
+
+void MainWindow::downloadFiles()
+{
+    DownloadWidget *dlw = new DownloadWidget();
+
+    connect(dlw,
+            SIGNAL(finished()),
+            this,
+            SIGNAL(updateFileList()));
+
+    dlw->show();
+
+}
+
