@@ -17,16 +17,34 @@
 #define MAINWINDOW_H
 
 #include <QMainWindow>
+#include <QtGui>
+#include <QFlags>
+
+#include "trainingselectionview.h"
+#include "querymeesettings.h"
+#include "downloadwidget.h"
 
 class QAction;
 
 class MainWindow : public QMainWindow
 {
+    Q_OBJECT
+
 public:
     MainWindow();
+//    TrainingSelectionView* trainingView;
+//    DownloadWidget *dlw;
+signals:
+    void updateFileList();
+
+public slots:
+    void downloadFiles();
+
 private:
     QAction *settingAction;
+    QAction *downloadAction;
     QMenu *mainMenu;
+
     void createActions();
     void createMenus();
 };
