@@ -25,12 +25,7 @@
 #include <QDir>
 #include <QDebug>
 
-// Constants
-#ifdef Q_WS_MAEMO_5
-    #define DICTIONARY_PATH "/MyDocs/Querymee/"
-#else
-    #define DICTIONARY_PATH "/.querymee/dictionaries"
-#endif
+#include <querymee_defaults.h>
 
 QueryMeeSettings* QueryMeeSettings::m_Instance = 0;
 
@@ -38,8 +33,8 @@ QueryMeeSettings* QueryMeeSettings::instance()
 {
     if(!m_Instance) {
         m_Instance = new QueryMeeSettings(QCoreApplication::instance());
-        m_Instance->init();
     }
+    m_Instance->init();
     return m_Instance;
 }
 
@@ -62,7 +57,8 @@ void QueryMeeSettings::init()
     if(pathExist) {
         QFileInfoList dictionaries = dir.entryInfoList(QDir::Files, QDir::Name);
         foreach(QFileInfo info, dictionaries) {
-            m_Dictionaries.insert(info.fileName(),info.absoluteFilePath());
+            if (info.fileName().endsWith(".kvtml",Qt::CaseInsensitive))
+                m_Dictionaries.insert(info.fileName(),info.absoluteFilePath());
         }
     }
 }
